import webui_data.routes

webui_data.routes.main()